package net.minecraft.src;

import java.util.Iterator;
import java.util.TreeMap;

public class EntityNameplateMaid extends EntityNameplate
{
    public long maidUniqueID = 0L;
    public int maidColor;
    
    public EntityNameplateMaid(World var1)
    {
        super(var1);
    }
    public EntityNameplateMaid(World world, EntityLiving owner)
    {
        super(world, owner);
    }

    public void writeEntityToNBT(NBTTagCompound nbttagcompound)
    {
        super.writeEntityToNBT(nbttagcompound);
        if (this.entityOwner != null)
        {
            nbttagcompound.setInteger("MaidColor", ((EntityLittleMaid)this.entityOwner).getMaidColor());
            nbttagcompound.setLong("MaidUniqueID", this.maidUniqueID);
        }
    }
    protected void readEntityFromNBT(NBTTagCompound nbttagcompound)
    {
        super.readEntityFromNBT(nbttagcompound);
        this.maidColor = nbttagcompound.getInteger("MaidColor");
        this.maidUniqueID = nbttagcompound.getLong("MaidUniqueID");
    }

    protected boolean setOwnerEntity(EntityLiving owner)
    {
        if(! mod_Nameplate.EntityNameable(owner)) {
            return false;
        }
        if(! (owner instanceof EntityLittleMaid)) {
            return false;
        }

        if(! super.setOwnerEntity(owner)) return false;

        EntityLittleMaid var3 = (EntityLittleMaid)owner;
        this.maidColor = var3.getMaidColor();
        this.maidUniqueID = var3.maidContractTime;
        return true;
    }

    protected EntityLiving FindOwner()
    {
        // owner候補を探す
        TreeMap<Float, EntityLiving> candidates = SearchOwnerCandidated();

        // unique IDで探す
        Iterator<EntityLiving> var3 = candidates.values().iterator();
        while (var3.hasNext())
        {
            EntityLiving var4 = var3.next();

            if(! (var4 instanceof EntityLittleMaid))
            {
                continue;
            }

            EntityLittleMaid var5 = (EntityLittleMaid)var4;
            if (var5.isMaidContract())
            {
                if(this.maidUniqueID != 0L && this.maidUniqueID == var5.maidContractTime)
                {
                    System.out.println(String.format("matched unique ID(%d)", new Object[] {Long.valueOf(this.maidUniqueID)}));
                    return var4;
                }
            }
        }

        // 距離と色で探す
        var3 = candidates.values().iterator();
        while (var3.hasNext())
        {
            EntityLiving var4 = var3.next();

            if(! (var4 instanceof EntityLittleMaid))
            {
                continue;
            }

            EntityLittleMaid var5 = (EntityLittleMaid)var4;
            if (var5.isMaidContract())
            {
                if(this.maidColor == var5.getMaidColor())
                {
                    return var4;
                }
            }
        }

        return null;
    }
}
